//
//  CrearUsuarioViewController.swift
//  PowerFitnessApp
//
//  Created by user on 19/7/22.
//

import UIKit

class CrearUsuarioViewController: UIViewController {
    
    private let logo: UIImageView = {
        let logo = UIImageView()
        logo.image = UIImage(named: "logo_pfitness")
        logo.contentMode = .scaleAspectFit
        return logo
    }()
    
    private let nameField: UITextField = {
        let nameField = UITextField()
        nameField.attributedPlaceholder = NSAttributedString(
            string: "Nombre Completo",
            attributes: [NSAttributedString.Key.foregroundColor: UIColor.black]
        )
        nameField.layer.borderWidth = 1
        nameField.layer.borderColor = UIColor.black.cgColor
        nameField.backgroundColor = .none
        nameField.autocapitalizationType = .none
        nameField.leftViewMode = .always
        nameField.leftView = UIView(frame: CGRect(x: 0, y: 0, width: 10, height: 0))
        nameField.layer.cornerRadius = 10
        nameField.layer.masksToBounds = true
        return nameField
    }()
    
    private let emailField: UITextField = {
        let emailField = UITextField()
        emailField.attributedPlaceholder = NSAttributedString(
            string: "Correo Electrónico",
            attributes: [NSAttributedString.Key.foregroundColor: UIColor.black]
        )
        emailField.layer.borderWidth = 1
        emailField.layer.borderColor = UIColor.black.cgColor
        emailField.backgroundColor = .none
        emailField.autocapitalizationType = .none
        emailField.leftViewMode = .always
        emailField.leftView = UIView(frame: CGRect(x: 0, y: 0, width: 10, height: 0))
        emailField.layer.cornerRadius = 10
        emailField.layer.masksToBounds = true
        return emailField
    }()
    
    private let passwordField: UITextField = {
        let passwordField = UITextField()
        passwordField.attributedPlaceholder = NSAttributedString(
            string: "Contraseña",
            attributes: [NSAttributedString.Key.foregroundColor: UIColor.black]
        )
        passwordField.layer.borderWidth = 1
        passwordField.isSecureTextEntry = true
        passwordField.layer.borderColor = UIColor.black.cgColor
        passwordField.backgroundColor = .none
        passwordField.autocapitalizationType = .none
        passwordField.leftViewMode = .always
        passwordField.leftView = UIView(frame: CGRect(x: 0, y: 0, width: 10, height: 0))
        passwordField.layer.cornerRadius = 10
        passwordField.layer.masksToBounds = true
        return passwordField
    }()
    
    private let button: UIButton = {
        let button = UIButton()
        button.backgroundColor = .systemOrange
        button.setTitle("Darse de Alta", for: .normal)
        button.setTitleColor(.black, for: .normal)
        button.layer.cornerRadius = 10
        button.layer.masksToBounds = true
        return button
    }()
    
    private let cancelar: UIButton = {
        let button = UIButton()
        button.setTitle("Cancelar", for: .normal)
        button.setTitleColor(.black, for: .normal)
        button.titleLabel?.font = UIFont.systemFont(ofSize: 16)
        return button
    }()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        let backgroundImage = UIImageView(frame: UIScreen.main.bounds)
        backgroundImage.image = UIImage(named: "back_image.jpeg")
        backgroundImage.contentMode = .scaleAspectFill
        self.view.insertSubview(backgroundImage, at: 0)
        let blurEffect = UIBlurEffect(style: .systemUltraThinMaterialLight)
        let blurredEffectView = UIVisualEffectView(effect: blurEffect)
        blurredEffectView.frame = backgroundImage.bounds
        view.addSubview(blurredEffectView)
        
        view.addSubview(logo)
        view.addSubview(nameField)
        view.addSubview(emailField)
        view.addSubview(passwordField)
        view.addSubview(button)
        view.addSubview(cancelar)
        button.addTarget(self, action: #selector(didTapButton), for: .touchUpInside)
        cancelar.addTarget(self, action: #selector(didTapCancelar), for: .touchUpInside)
    }
    
    override func viewDidLayoutSubviews() {
        super.viewDidLayoutSubviews()
        logo.frame = CGRect(x: 0,
                            y: (nameField.frame.origin.y-logo.frame.size.height)+view.frame.size.height*0.03,
                            width: view.frame.size.width,
                            height: 400)
        nameField.frame = CGRect(x: view.frame.size.width*0.05,
                                 y: (view.frame.size.height/2)-25,
                                 width: view.frame.size.width-40,
                                 height: 50)
        emailField.frame = CGRect(x: view.frame.size.width*0.05,
                                  y: nameField.frame.origin.y+nameField.frame.size.height+10,
                                  width: view.frame.size.width-40,
                                  height: 50)
        passwordField.frame = CGRect(x: view.frame.size.width*0.05,
                                     y: emailField.frame.origin.y+emailField.frame.size.height+10,
                                     width: view.frame.size.width-40,
                                     height: 50)
        button.frame = CGRect(x: view.frame.size.width*0.05,
                              y: passwordField.frame.origin.y+passwordField.frame.size.height+20,
                              width: view.frame.size.width-40,
                              height: 50)
        cancelar.frame = CGRect(x: view.frame.size.width/2 - (50),
                                y: button.frame.origin.y+button.frame.size.height+15,
                                width: 100,
                                height: 20)
    }
    
    @objc private func didTapCancelar() {
        print("...   se ha pulsado cancelar   ...")
        let volverInicio = LoginViewController(nibName: nil, bundle: nil)
        volverInicio.modalPresentationStyle = .fullScreen
        present(volverInicio, animated: true, completion: nil)
    }
    
    @objc private func didTapButton() {
        print("...   se ha pulsado volver a inicio de sesion   ...")
        let email: String = emailField.text!
        let contraseña: String = passwordField.text!
        let nombre: String = nameField.text!
        if !email.isEmpty && !contraseña.isEmpty && !nombre.isEmpty {
            
            AuthManager.shared.signUp(email: email, password: contraseña) { [weak self] success in
                if success {
                    let newUser = User(nombre: nombre, email: email)
                    DatabaseManager.shared.insertUsuario(user: newUser) { inserted in
                        guard inserted else {
                            return
                        }
                        
                        print("...   se ha creado la cuenta   ...")
                        UserDefaults.standard.set(email, forKey: "email")
                        UserDefaults.standard.set(nombre, forKey: "nombre")
                        
                        DispatchQueue.main.async {
                            let volverInicio = LoginViewController(nibName: nil, bundle: nil)
                            volverInicio.modalPresentationStyle = .fullScreen
                            self?.present(volverInicio, animated: true, completion: nil)
                        }
                        
                    }
                } else {
                    print("...   fallo al crear la cuenta   ...")
                    self?.noCreado()
                }
            }
            
        } else {
            print("...   faltan datos   ...")
            faltanCredenciales()
        }
    }
    
    func faltanCredenciales() {
        let alert = UIAlertController(title: "",
                                      message: "Completa todos los campos para darte de alta",
                                      preferredStyle: .alert)
        alert.addAction(UIAlertAction(title: "OK",
                                      style: .cancel,
                                      handler: nil
                                     ))
        self.present(alert, animated: true, completion: nil)
    }
    func noCreado() {
        let alert = UIAlertController(title: "",
                                      message: "No se ha podido crear el usuario\n(contraseña mínima de seis carácteres y sin espacios)",
                                      preferredStyle: .alert)
        alert.addAction(UIAlertAction(title: "OK",
                                      style: .cancel,
                                      handler: nil
                                     ))
        self.present(alert, animated: true, completion: nil)
    }
    
}


