//
//  NovedadesTableViewCell.swift
//  PowerFitnessApp
//
//  Created by user on 25/7/22.
//

import UIKit

class NovedadesTableViewCellViewModel {
    let titulo: String
    let imagen: URL?
    var imagenDatos: Data?
    let cuerpo: String
    
    
    init(titulo: String, imagen: URL?, cuerpo: String) {
        self.titulo = titulo
        self.imagen = imagen
        self.cuerpo = cuerpo
    }
}

class NovedadesTableViewCell: UITableViewCell {
    
    static let identifier = "NovedadesTableViewCell"
    
    private let labelTitulo: UILabel = {
        let label = UILabel()
        label.numberOfLines = 0
        return label
    }()
    private let appImageView: UIImageView = {
        let imageView = UIImageView()
        imageView.contentMode = .scaleAspectFill
        return imageView
    }()
    private let labelCuerpo: UILabel = {
        let label = UILabel()
        label.numberOfLines = 0
        return label
    }()
    
    override init(style: UITableViewCell.CellStyle, reuseIdentifier: String?) {
        super.init(style: style, reuseIdentifier: reuseIdentifier)
        contentView.addSubview(labelTitulo)
        contentView.addSubview(appImageView)
        contentView.addSubview(labelCuerpo)
    }
    
    required init?(coder: NSCoder) {
        fatalError()
    }
    
    override func layoutSubviews() {
        super.layoutSubviews()
        
        labelTitulo.frame = CGRect(x: 0,
                                   y: 0,
                                   width: contentView.frame.size.width,
                                   height: 40)
        labelTitulo.font = .systemFont(ofSize: 24)
        labelTitulo.textAlignment = .center
        labelTitulo.backgroundColor = .systemGray6
        
        appImageView.frame = CGRect(x: 0,
                                    y: labelTitulo.frame.origin.y+labelTitulo.frame.size.height,
                                    width: contentView.frame.size.width,
                                    height: contentView.frame.size.width) //imageSize-10)
        
        labelCuerpo.frame = CGRect(x: 0,
                                   y: appImageView.frame.origin.y+appImageView.frame.size.height,
                                   width: contentView.frame.size.width,
                                   height: 225)
        labelCuerpo.font = .systemFont(ofSize: 16)
        labelCuerpo.textAlignment = .center
    }
    
    override func prepareForReuse() {
        super.prepareForReuse()
        labelTitulo.text = nil
        appImageView.image = nil
        labelCuerpo.text = nil
    }
    
    public func configure(with viewModel: NovedadesTableViewCellViewModel) {
        labelTitulo.text = viewModel.titulo
        
        if let data = viewModel.imagenDatos {
            appImageView.image = UIImage(data: data)
        }
        else if let url = viewModel.imagen {
            // fetch image & cache
            let task = URLSession.shared.dataTask(with: url) { [weak self] data, _, _ in
                guard let data = data else {
                    return
                }
                viewModel.imagenDatos = data
                DispatchQueue.main.async {
                    self?.appImageView.image = UIImage(data: data)
                }
            }
            task.resume()
        }
        
        labelCuerpo.text = viewModel.cuerpo
    }
    
}


