//
//  SocialMediaTableViewCell.swift
//  PowerFitnessApp
//
//  Created by user on 3/7/22.
//

import UIKit

struct SocialMediaTableViewCellViewModel {
    let image: UIImage?
    let title: String
}

class SocialMediaTableViewCell: UITableViewCell {
    
    static let identifier = "SocialMediaTableViewCellViewModel"
    
    private let appImageView: UIImageView = {
        let imageView = UIImageView()
        imageView.contentMode = .scaleAspectFill
        return imageView
    }()
    private let label: UILabel = {
        let label = UILabel()
        label.numberOfLines = 0
        return label
    }()
    
    override init(style: UITableViewCell.CellStyle, reuseIdentifier: String?) {
        super.init(style: style, reuseIdentifier: reuseIdentifier)
        contentView.addSubview(label)
        contentView.addSubview(appImageView)
    }
    
    required init?(coder: NSCoder) {
        fatalError()
    }
    
    override func layoutSubviews() {
        super.layoutSubviews()
        
        let imageSize: CGFloat = contentView.frame.size.height
        appImageView.frame = CGRect(x: contentView.frame.size.width*0.2,
                                    y: (imageSize/2)-((imageSize-10)/2),
                                    width: imageSize,
                                    height: imageSize-10)
        label.frame = CGRect(x: contentView.frame.size.width*0.2 + imageSize,
                             y: (imageSize/2)-((imageSize-10)/2),
                             width: contentView.frame.size.width - 20 - imageSize,
                             height: imageSize-10)
        label.font = .systemFont(ofSize: 16)
        //label.textAlignment = .center
    }
    
    public func configure(with viewModel: SocialMediaTableViewCellViewModel) {
        label.text = viewModel.title
        appImageView.image = viewModel.image
    }
    
}


