//
//  TrainerInfoTableViewCell.swift
//  PowerFitnessApp
//
//  Created by user on 3/7/22.
//

import UIKit

struct TrainerInfoTableViewCellViewModel {
    let image: UIImage?
    let title: String
}

class TrainerInfoTableViewCell: UITableViewCell {
    
    static let identifier = "TrainerInfoTableViewCellViewModel"
    
    private let trainerImageView: UIImageView = {
        let imageView = UIImageView()
        imageView.contentMode = .scaleAspectFill
        return imageView
    }()
    private let label: UILabel = {
        let label = UILabel()
        label.numberOfLines = 0
        return label
    }()
    
    override init(style: UITableViewCell.CellStyle, reuseIdentifier: String?) {
        super.init(style: style, reuseIdentifier: reuseIdentifier)
        contentView.addSubview(label)
        contentView.addSubview(trainerImageView)
    }
    
    required init?(coder: NSCoder) {
        fatalError()
    }
    
    override func layoutSubviews() {
        super.layoutSubviews()
        
        let imageSize: CGFloat = contentView.frame.size.height
        trainerImageView.frame = CGRect(x: contentView.frame.size.width*0.04, y: 0, width: imageSize, height: imageSize)
        // para dar forma redondeada a la foto
        trainerImageView.layer.cornerRadius = trainerImageView.frame.size.height / 2
        trainerImageView.clipsToBounds = true
        label.frame = CGRect(x: contentView.frame.size.width*0.04 + imageSize, y: 0,
                             width: contentView.frame.size.width - 20 - imageSize,
                             height: imageSize)
        label.font = .systemFont(ofSize: 20)
    }
    
    public func configure(with viewModel: TrainerInfoTableViewCellViewModel) {
        label.text = viewModel.title
        trainerImageView.image = viewModel.image
    }
    
}


