//
//  ViewController.swift
//  PowerFitnessApp
//
//  Created by user on 3/7/22.
//

import UIKit
import FirebaseAuth

class ContainerViewController: UIViewController {
    
    enum MenuState {
        case opened
        case closed
    }
    private var menuState: MenuState = .closed
    
    let menuVC = MenuViewController()
    let infoVC = InfoViewController()
    var navVC: UINavigationController? // boton para abrir el menu
    lazy var novedadesVC = NovedadesViewController() //lazy, no se cra la vista directamente al iniciar la app
    lazy var dietasVC = DietasViewController(currentEmail: UserDefaults.standard.string(forKey: "email"))
    lazy var rutinasVC = RutinasViewController(currentEmail: UserDefaults.standard.string(forKey: "email"))
    lazy var actividadesVC = ActividadesViewController()
    lazy var horariosVC = HorariosViewController()
    
    var logoutVC: UINavigationController? // boton para cerrar sesion
    let loginVC = LoginViewController()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        view.backgroundColor = .blue
        addChildVCs()
    }
    
    private func addChildVCs() {
        // vista del menu
        menuVC.delegate = self
        addChild(menuVC)
        view.addSubview(menuVC.view)
        menuVC.didMove(toParent: self)
        
        // vista de home
        infoVC.delegate = self
        let navVC = UINavigationController(rootViewController: infoVC)
        addChild(navVC)
        view.addSubview(navVC.view)
        navVC.didMove(toParent: self)
        self.navVC = navVC
    }
    
}

extension ContainerViewController: InfoViewControllerDelegate {
    
    func didTapMenuButton() {
        toggleMenu(completion: nil)
    }
    
    // FUNCION PARA CERARR SESION Y VOLVER AL LOGIN
    func didTapLogoutButton() {
        let alerta = UIAlertController(title: "Cerrar Sesión", message: "¿Seguro que quieres cerrar la sesión?", preferredStyle: .actionSheet)
        alerta.addAction(UIAlertAction(title: "Cancelar", style: .cancel, handler: nil))
        alerta.addAction(UIAlertAction(title: "Cerrar Sesión", style: .destructive, handler: { _ in
            do {
                try FirebaseAuth.Auth.auth().signOut() // sign out - desconectar
                print("...   has cerrado sesion   ...")
                // volvemos al login
                let login = LoginViewController(nibName: nil, bundle: nil)
                login.modalPresentationStyle = .fullScreen
                self.present(login, animated: true, completion: nil)
            }
            catch {
                print("...   error al cerrar la sesion   ...")
            }
        }))
        present(alerta, animated: true)
    }
    
    
    func toggleMenu(completion: (() -> Void)?) {
        // animacion
        switch menuState {
        case .closed:
            // abrir el menu
            UIView.animate(withDuration: 0.5, delay: 0, usingSpringWithDamping: 0.8, initialSpringVelocity: 0, options: .curveEaseIn) {
                self.navVC?.view.frame.origin.x = self.infoVC.view.frame.size.width * 0.7
            } completion: { [weak self] done in
                if done {
                    self?.menuState = .opened
                }
            }
            
        case .opened:
            // cerrar el menu
            UIView.animate(withDuration: 0.5, delay: 0, usingSpringWithDamping: 0.8, initialSpringVelocity: 0, options: .curveEaseIn) {
                self.navVC?.view.frame.origin.x = 0 //origin ahora es '0' como era antes
            } completion: { [weak self] done in
                if done {
                    self?.menuState = .closed
                    DispatchQueue.main.async {
                        completion?()
                    }
                }
            }
        }
    }
    
}

extension ContainerViewController: MenuViewControllerDelegate {
    
    func didSelect(menuItem: MenuViewController.MenuOptions) {
        toggleMenu(completion: nil)
        switch menuItem {
        case .info:
            self.resetToInfo()
        case .novedades:
            self.addNovedades()
        case .dietas:
            self.addDietas()
        case .rutinas:
            self.addRutinas()
        case .actividades:
            self.addActividades()
        case .horarios:
            self.addHorarios()
        }
    }
    
    func resetToInfo() {
        novedadesVC.view.removeFromSuperview()
        novedadesVC.didMove(toParent: nil)
        dietasVC.view.removeFromSuperview()
        dietasVC.didMove(toParent: nil)
        rutinasVC.view.removeFromSuperview()
        rutinasVC.didMove(toParent: nil)
        horariosVC.view.removeFromSuperview()
        horariosVC.didMove(toParent: nil)
        actividadesVC.view.removeFromSuperview()
        actividadesVC.didMove(toParent: nil)
        infoVC.title = "Sobre Nosotros"
    }
    
    func addNovedades() {
        let vc = novedadesVC
        infoVC.addChild(vc)
        infoVC.view.addSubview(vc.view)
        vc.view.frame = view.frame
        vc.didMove(toParent: infoVC)
        infoVC.title = vc.title
    }
    
    func addDietas() {
        let vc = dietasVC
        infoVC.addChild(vc)
        infoVC.view.addSubview(vc.view)
        vc.view.frame = view.frame
        vc.didMove(toParent: infoVC)
        infoVC.title = vc.title
    }
    
    func addRutinas() {
        let vc = rutinasVC
        infoVC.addChild(vc)
        infoVC.view.addSubview(vc.view)
        vc.view.frame = view.frame
        vc.didMove(toParent: infoVC)
        infoVC.title = vc.title
    }
    
    func addHorarios() {
        let vc = horariosVC
        infoVC.addChild(vc)
        infoVC.view.addSubview(vc.view)
        vc.view.frame = view.frame
        vc.didMove(toParent: infoVC)
        infoVC.title = vc.title
    }
    
    func addActividades() {
        let vc = actividadesVC
        infoVC.addChild(vc)
        infoVC.view.addSubview(vc.view)
        vc.view.frame = view.frame
        vc.didMove(toParent: infoVC)
        infoVC.title = vc.title
    }
    
}


