//
//  InfoViewController.swift
//  PowerFitnessApp
//
//  Created by user on 3/7/22.
//

import UIKit
import MapKit

//      //      //        //      //
protocol InfoViewControllerDelegate: AnyObject{
    func didTapMenuButton()
    func didTapLogoutButton()
}
//      //      //        //      //

struct TextCellViewModel {
    let text: String
    let font: UIFont
}

enum sectionType {
    case photosGym
    case infoGym(viewModels: TextCellViewModel)
    case trainerInfo(viewModels: TrainerInfoTableViewCellViewModel)
    case socialMedia1(viewModels: SocialMediaTableViewCellViewModel)
    case socialMedia2(viewModels: SocialMediaTableViewCellViewModel)
    case socialMedia3(viewModels: SocialMediaTableViewCellViewModel)
    case socialMedia4(viewModels: SocialMediaTableViewCellViewModel)
    case location(viewModels: LocationTableViewCellViewModel)
    case mapLoc
    
    var title: String? {
        switch self {
        case .trainerInfo:
            return "Entrenador"
        case .location:
            return "Localización"
        default:
            return nil
        }
    }
}

class InfoViewController: UIViewController, UITableViewDelegate, UITableViewDataSource {
    
    //      //      //        //      //
    weak var delegate: InfoViewControllerDelegate?
    //      //      //        //      //
    
    
    private var tableView =  UITableView()
    
    private var sections = [sectionType]()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        view.backgroundColor = .systemBackground
        
        //                  //                   //                   //                   //
        title = "Sobre Nosotros"
        navigationItem.leftBarButtonItem = UIBarButtonItem(image: UIImage(systemName: "list.bullet", withConfiguration: UIImage.SymbolConfiguration(hierarchicalColor: .orange)),style: .done, target: self, action: #selector(didTapMenuButton))
        navigationItem.rightBarButtonItem = UIBarButtonItem(image: UIImage(systemName: "rectangle.portrait.and.arrow.right", withConfiguration: UIImage.SymbolConfiguration(hierarchicalColor: .orange)),style: .done,target: self,action: #selector(didTapLogoutButton))
        //                  //                   //                   //                     //
        
        
        configureSections()
        
        tableView = UITableView(frame: self.view.bounds)
        //tableView.contentInset = UIEdgeInsets(top: 0, left: -15, bottom: 0, right: 0)
        //tableView.separatorInset = UIEdgeInsets(top: 0, left: -15, bottom: 0, right: 0)
        tableView.separatorColor = .systemBackground // blanco
        // para quitar el frame por defecto que se queda por encima de la cabecra de cada celda
        tableView.sectionHeaderTopPadding = 0.0
        tableView.frame = CGRect(x: 0, y: 0, width: view.frame.size.width, height: view.frame.height)
        tableView.register(UITableViewCell.self,
                           forCellReuseIdentifier: "cell")
        // registra la celda de la info del entrenador
        tableView.register(TrainerInfoTableViewCell.self,
                           forCellReuseIdentifier: TrainerInfoTableViewCell.identifier)
        // registra las celdas de las redes sociales/mail/telefono
        tableView.register(SocialMediaTableViewCell.self,
                           forCellReuseIdentifier: SocialMediaTableViewCell.identifier)
        // registra la celdas para la localizacion
        tableView.register(LocationTableViewCell.self,
                           forCellReuseIdentifier: LocationTableViewCell.identifier)
        view.addSubview(tableView)
        tableView.delegate = self
        tableView.dataSource = self
    }
    
    private func configureSections() {
        sections.append(.photosGym)
        
        sections.append(.infoGym(viewModels:
            TextCellViewModel(
                text: "Gimnasio localizado en la pequeña localidad de Ibi, situada en la provincia de Alicante. Orientado a entrenamiento personal con clases dirigidas o entrenamiento común asistido. Posibilidad de dietas o rutinas personalizadas.\n\nHorarios:\nLunes a Viernes\n\t10:00-14:00 y 17:00-21:00",
                font: .systemFont(ofSize: 16)
            )
        ))
        
        sections.append(.trainerInfo(viewModels:
            TrainerInfoTableViewCellViewModel(
                image: UIImage(named: "entrenador"),
                title: "\tNombre Entrenador"
            )
        ))
        sections.append(.socialMedia1(viewModels:
            SocialMediaTableViewCellViewModel(
                image: UIImage(systemName: "envelope", withConfiguration: UIImage.SymbolConfiguration(hierarchicalColor: .orange)),
                title: "\tCorreo Electrónico"
            )
        ))
        sections.append(.socialMedia2(viewModels:
            SocialMediaTableViewCellViewModel(
                image: UIImage(systemName: "play.rectangle", withConfiguration: UIImage.SymbolConfiguration(hierarchicalColor: .orange)),
                title: "\tYouTube"
            )
        ))
        sections.append(.socialMedia3(viewModels:
            SocialMediaTableViewCellViewModel(
                image: UIImage(systemName: "phone", withConfiguration: UIImage.SymbolConfiguration(hierarchicalColor: .orange)),
                title: "\tTeléfono"
            )
        ))
        sections.append(.socialMedia4(viewModels:
                                        SocialMediaTableViewCellViewModel(
                                            image: UIImage(systemName: "rectangle.3.group.bubble.left", withConfiguration: UIImage.SymbolConfiguration(hierarchicalColor: .orange)),
                                            title: "\tInstagram"
                                        )
                                     ))
        sections.append(.location(viewModels:
                                    LocationTableViewCellViewModel(
                                        image: UIImage(systemName: "map", withConfiguration: UIImage.SymbolConfiguration(hierarchicalColor: .orange)),
                                        title: "Calle Virgen de los Desamparados, 21 03440 Ibi"
                                    )
                                 ))
        sections.append(.mapLoc)
    }
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return sections.count
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, titleForHeaderInSection section: Int) -> String? {
        let sectionType = sections[section]
        return sectionType.title
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        let sectionType = sections[indexPath.section]
        
        switch sectionType {
            
        case .photosGym:
            break
            
        case .infoGym:
            break
            
        case .trainerInfo:
            break
            
        case .socialMedia1:
            // MAIL
            guard let url = NSURL(string: "mailto:morabuitragokevin@gmail.com") else {
                return
            }
            if #available(iOS 10.0, *) {
                UIApplication.shared.open(url as URL, options: [:], completionHandler: nil)
            } else {
                UIApplication.shared.openURL(url as URL)
            }
            
        case .socialMedia2:
            /*----Actualizar el codigo fuente de info.plist y añadir esto----
             <key>LSApplicationQueriesSchemes</key>
             <array>
             <string>instagram</string>
             <string>youtube</string>
             </array>
             ---------------------------------------------------------------*/
            // YOUTUBE
            if let youtubeURL = URL(string: "youtube://Z-48u_uWMHY"),
               UIApplication.shared.canOpenURL(youtubeURL) {
                // app
                UIApplication.shared.open(youtubeURL, options: [:], completionHandler: nil)
            } else if let youtubeURL = URL(string: "https://www.youtube.com/watch?v=Z-48u_uWMHY") {
                // safari
                UIApplication.shared.open(youtubeURL, options: [:], completionHandler: nil)
            }
            
        case .socialMedia3:
            // TELEFONO
            guard let url = NSURL(string: "tel://601125741") else {
                return
            }
            if #available(iOS 10.0, *) {
                UIApplication.shared.open(url as URL, options: [:], completionHandler: nil)
            } else {
                UIApplication.shared.openURL(url as URL)
            }
            
        case .socialMedia4:
            // INSTAGRAM
            let appURL = URL(string: "instagram://user?username=fcbarcelona")!
            if UIApplication.shared.canOpenURL(appURL) {
                UIApplication.shared.open(appURL, options: [:], completionHandler: nil)
            } else {
                // if Instagram app is not installed, open URL inside Safari
                let webURL = URL(string: "https://instagram.com/fcbarcelona")!
                UIApplication.shared.open(webURL, options: [:], completionHandler: nil)
            }
            
        case .location:
            //38.624747, -0.568229
            let latitude: CLLocationDegrees = Double(38.624747)
            let longitude: CLLocationDegrees = Double(-0.568229)
            let regionDistance:CLLocationDistance = 10000
            let coordinates = CLLocationCoordinate2DMake(latitude, longitude)
            let regionSpan = MKCoordinateRegion(center: coordinates, latitudinalMeters: regionDistance, longitudinalMeters: regionDistance)
            let options = [
                MKLaunchOptionsMapCenterKey: NSValue(mkCoordinate: regionSpan.center),
                MKLaunchOptionsMapSpanKey: NSValue(mkCoordinateSpan: regionSpan.span)
            ]
            let placemark = MKPlacemark(coordinate: coordinates, addressDictionary: nil)
            let mapItem = MKMapItem(placemark: placemark)
            mapItem.name = "Power Fitness"
            mapItem.openInMaps(launchOptions: options)
            
        case .mapLoc:
            break
            
        }
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let sectionType = sections[indexPath.section]
        switch sectionType {
            
        case .photosGym:
            let cell = tableView.dequeueReusableCell(
                withIdentifier: "cell",
                for: indexPath
            )
            let imagen = UIImage(named: "gym1")
            cell.imageView?.image = imagen
            cell.imageView?.layer.cornerRadius = 24
            cell.imageView?.layer.masksToBounds = false
            cell.imageView?.clipsToBounds = true
            return cell
            
        case .infoGym(let viewModels):
            //let viewModel = viewModels
            let cell = tableView.dequeueReusableCell(
                withIdentifier: "cell",
                for: indexPath
            )
            cell.configure(with: viewModels)
            return cell
            
        case .trainerInfo(let viewModels):
            guard let cell = tableView.dequeueReusableCell(
                withIdentifier: TrainerInfoTableViewCell.identifier,
                for: indexPath
            ) as? TrainerInfoTableViewCell else {
                fatalError()
            }
            cell.configure(with: viewModels)
            return cell
            
        case .socialMedia1(let viewModels):
            guard let cell = tableView.dequeueReusableCell(
                withIdentifier: SocialMediaTableViewCell.identifier,
                for: indexPath
            ) as? SocialMediaTableViewCell else {
                fatalError()
            }
            cell.configure(with: viewModels)
            return cell
            
        case .socialMedia2(let viewModels):
            guard let cell = tableView.dequeueReusableCell(
                withIdentifier: SocialMediaTableViewCell.identifier,
                for: indexPath
            ) as? SocialMediaTableViewCell else {
                fatalError()
            }
            cell.configure(with: viewModels)
            return cell
            
        case .socialMedia3(let viewModels):
            guard let cell = tableView.dequeueReusableCell(
                withIdentifier: SocialMediaTableViewCell.identifier,
                for: indexPath
            ) as? SocialMediaTableViewCell else {
                fatalError()
            }
            cell.configure(with: viewModels)
            return cell
            
        case .socialMedia4(let viewModels):
            guard let cell = tableView.dequeueReusableCell(
                withIdentifier: SocialMediaTableViewCell.identifier,
                for: indexPath
            ) as? SocialMediaTableViewCell else {
                fatalError()
            }
            cell.configure(with: viewModels)
            return cell
            
        case .location(let viewModels):
            guard let cell = tableView.dequeueReusableCell(
                withIdentifier: LocationTableViewCell.identifier,
                for: indexPath
            ) as? LocationTableViewCell else {
                fatalError()
            }
            cell.configure(with: viewModels)
            return cell
            
        case .mapLoc:
            let cell = tableView.dequeueReusableCell(
                withIdentifier: "cell",
                for: indexPath
            )
            // crea el mapa
            let mapa = MKMapView(frame: CGRect(x: 0,
                                               y: 0,
                                               width: view.frame.size.width,
                                               height: view.frame.size.width)
            )
            cell.contentView.addSubview(mapa)
            // zoom a la zona del mapa donde esta el gym
            let coordinate = CLLocationCoordinate2D(
                latitude: 38.624747,
                longitude: -0.568229)
            mapa.setRegion(MKCoordinateRegion(
                center: coordinate,
                span: MKCoordinateSpan(latitudeDelta: 0.003,
                                       longitudeDelta: 0.003)),
                           animated: false)
            // añade la marca exacta donde esta ubicado el gym
            let annotation = MKPointAnnotation()
            annotation.title = "Power Fitness"
            annotation.coordinate = CLLocationCoordinate2D(latitude: 38.624747,
                                                           longitude: -0.568229)
            mapa.addAnnotation(annotation)
            return cell
            
        }
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        let sectionType = sections[indexPath.section]
        switch sectionType {
            
        case .photosGym:
            return view.frame.size.width*0.549333334 // multiplicamos el ancho de la pantalla por 0,55 para que el alto de la celda sea el 55% del ancho de la pantalla (este calculo depende del ancho de la imagen)
            
        case .infoGym:
            return UITableView.automaticDimension
            
        case .trainerInfo:
            return 60
            
        case .socialMedia1:
            return 30
            
        case .socialMedia2:
            return 30
            
        case .socialMedia3:
            return 30
            
        case .socialMedia4:
            return 30
            
        case .location:
            return 30
            
        case .mapLoc:
            return view.frame.size.width
            
        }
    }
    
    
    
    //      //      //        //      //
    @objc func didTapMenuButton() {
        delegate?.didTapMenuButton()
    }
    @objc func didTapLogoutButton() {
        delegate?.didTapLogoutButton()
    }
    //      //      //        //      //
    
    
    
}

extension UITableViewCell {
    func configure(with viewModel: TextCellViewModel) {
        textLabel?.text = viewModel.text
        textLabel?.numberOfLines = 0
        textLabel?.font = viewModel.font
    }
}


