//
//  MenuViewController.swift
//  PowerFitnessApp
//
//  Created by user on 3/7/22.
//

import UIKit

protocol MenuViewControllerDelegate: AnyObject {
    func didSelect(menuItem: MenuViewController.MenuOptions)
}

class MenuViewController: UIViewController, UITableViewDelegate, UITableViewDataSource {
    
    weak var delegate: MenuViewControllerDelegate?
    
    enum MenuOptions: String, CaseIterable{
        // al ser iterable, el orden de aquí es como se muestran en la app
        case info = "Sobre Nosotros"
        case novedades = "Novedades"
        case dietas = "Dietas"
        case rutinas = "Rutinas"
        case actividades = "Actividades"
        case horarios = "Horarios"
        
        var imageName: String {
            switch self {
            case .info:
                return "house"
            case .novedades:
                return "newspaper"
            case .dietas:
                return "bolt.heart"
            case .rutinas:
                return "lungs"
            case .actividades:
                return "waveform.path.ecg"
            case .horarios:
                return "calendar.badge.clock"
            }
        }
    }

    private let tableView: UITableView = {
        let table = UITableView()
        table.backgroundColor = nil
        table.separatorColor = UIColor(red: 33/255.0, green: 33/255.0, blue: 33/255.0, alpha: 1)
        table.register(UITableViewCell.self, forCellReuseIdentifier: "cell")
        return table
    }()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        view.addSubview(tableView)
        tableView.delegate = self
        tableView.dataSource = self
        // color del menu
        view.backgroundColor = UIColor(red: 33/255.0, green: 33/255.0, blue: 33/255.0, alpha: 1)
    }
    
    // como queremos posicionar la tabla en la vista
    override func viewDidLayoutSubviews() {
        super.viewDidLayoutSubviews()
        tableView.frame = CGRect(x: 0, y: view.safeAreaInsets.top, width: view.bounds.size.width, height: view.bounds.size.height)
    }
    
    // indicamos el tamaño de la tabla contando las opciones del menu
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return MenuOptions.allCases.count
    }
    
    // creamos la cabecera de la tabla
    func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> UIView? {
        let headerView = UIView.init(frame: CGRect.init(x: 0, y: 0, width: tableView.frame.width, height: 50))
        let menuWidth = view.frame.size.width * 0.7
        let label = UILabel()
        label.frame = CGRect.init(x: (menuWidth/2)-45, y: 25-10, width: 80, height: 30)
        label.text = "Menú"
        label.font = .systemFont(ofSize: 30)
        label.textAlignment = .center
        label.textColor = .white
        headerView.addSubview(label)
        return headerView
    }
    func tableView(_ tableView: UITableView, heightForHeaderInSection section: Int) -> CGFloat {
        return view.frame.size.height/7 // 50
    }
    
    // añadimos a la tabla las opciones del menu
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "cell", for: indexPath)
        cell.textLabel?.text = MenuOptions.allCases[indexPath.row].rawValue
        cell.textLabel?.textColor = .white
        cell.imageView?.image = UIImage(systemName: MenuOptions.allCases[indexPath.row].imageName)
        cell.imageView?.tintColor = .white
        cell.backgroundColor = UIColor(red: 33/255.0, green: 33/255.0, blue: 33/255.0, alpha: 1)
        cell.contentView.backgroundColor = UIColor(red: 33/255.0, green: 33/255.0, blue: 33/255.0, alpha: 1)
        return cell
    }

    // damos funcionalidad a cada una de las lineas para que al pulsar respondan de alguna manera
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        tableView.deselectRow(at: indexPath, animated: true)
        let item = MenuOptions.allCases[indexPath.row]
        delegate?.didSelect(menuItem: item)
    }
    
}


