//
//  RutinasViewController.swift
//  PowerFitnessApp
//
//  Created by user on 3/7/22.
//

import UIKit
import PDFKit

class RutinasViewController: UIViewController, UITableViewDelegate, UITableViewDataSource, PDFViewDelegate {
    
    private var tableView =  UITableView()
    
    public func documentoPdf(ruta: String) {
        StorageManager.shared.downloadUrlForDocumentoPdf(path: ruta) { url in
            guard let url = url else {
                return
            }
            let task = URLSession.shared.dataTask(with: url) { data, _, _ in
                guard let data = data else {
                    return
                }
                DispatchQueue.main.async {
                    self.doc = PDFDocument(data: data)!
                }
            }
            task.resume()
        }
    }
    private var doc = PDFDocument()
    
    // muestra el email del usuario activo en la app
    let currentEmail: String
    init(currentEmail: String?) {
        self.currentEmail = currentEmail ?? "error"
        super.init(nibName: nil, bundle: nil)
    }
    required init?(coder: NSCoder) {
        fatalError()
    }
    
    private var rutinas: [DocumentoPdf] = []
    private func obtenerRutinas() {
        //print("XXXXX   obteniendo rutinas   XXXXX")
        DatabaseManager.shared.getRutinas(for: currentEmail) { [weak self] rutinas in
            self?.rutinas = rutinas
            //print("XXXXX   hay \(String(describing: self?.rutinas.count)) rutinas   XXXXX")
            DispatchQueue.main.async {
                self?.tableView.reloadData()
            }
        }
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        view.backgroundColor = .systemBackground
        
        title = "Rutinas"
        
        obtenerRutinas()
        
        tableView = UITableView(frame: self.view.bounds)
        tableView.separatorColor = .systemBackground
        // para quitar el frame por defecto que se queda por encima de la cabecra de cada celda
        tableView.sectionHeaderTopPadding = 0.0
        tableView.frame = CGRect(x: 0, y: 0, width: view.frame.size.width, height: view.frame.height)
        tableView.register(UITableViewCell.self,
                           forCellReuseIdentifier: "cell")
        view.addSubview(tableView)
        tableView.delegate = self
        tableView.dataSource = self
    }
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return rutinas.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let rutina = rutinas[indexPath.row]
        let cell = tableView.dequeueReusableCell(withIdentifier: "cell", for: indexPath)
        cell.textLabel?.text = rutina.titulo
        return cell
        
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        let rutina = rutinas[indexPath.row]
        switch indexPath.section {
        case 0:
            documentoPdf(ruta: rutina.storageUrl)
            // *HAY QUE ABRIR EL LECTOR DOS o TRES VECES PARA QUE CARGUE EL ARCHIVO CORRECTO*
            let lectorPdfView = LectorPdfViewController(doc: self.doc, nameDoc: rutina.titulo)
            self.present(lectorPdfView, animated: true, completion: nil)
        default:
            break
        }
    }
    
}


