//
//  PreviewActividadesTableViewCell.swift
//  PowerFitnessApp
//
//  Created by user on 25/7/22.
//

import UIKit

struct PreviewActividadTableViewCellViewModel {
    let titulo: String
    let imagen: UIImage?
    let hora: String
    let descripcion: String
}

class PreviewActividadTableViewCell: UITableViewCell {

    static let identifier = "PreviewActividadTableViewCellViewModel"
    
    private let labelTitulo: UILabel = {
        let label = UILabel()
        label.numberOfLines = 0
        return label
    }()
    private let appImageView: UIImageView = {
        let imageView = UIImageView()
        imageView.contentMode = .scaleAspectFill
        imageView.layer.cornerRadius = 10
        imageView.layer.masksToBounds = false
        imageView.clipsToBounds = true
        return imageView
    }()
    private let labelHora: UILabel = {
        let label = UILabel()
        label.numberOfLines = 0
        return label
    }()
    
    override init(style: UITableViewCell.CellStyle, reuseIdentifier: String?) {
        super.init(style: style, reuseIdentifier: reuseIdentifier)
        contentView.addSubview(labelTitulo)
        contentView.addSubview(appImageView)
        contentView.addSubview(labelHora)
    }
    
    required init?(coder: NSCoder) {
        fatalError()
    }
    
    override func layoutSubviews() {
        super.layoutSubviews()
        
        appImageView.frame = CGRect(x: contentView.frame.size.width*0.045,
                                    y: 5,
                                    width: 80,
                                    height: 60)
        
        labelHora.frame = CGRect(x: appImageView.frame.origin.x+appImageView.frame.size.width,
                                 y: 0,
                                 width: contentView.frame.size.width*0.7,
                                 height: 30)
        labelHora.font = .systemFont(ofSize: 20)
        labelHora.textAlignment = .center
        labelHora.textColor = .orange
        
        labelTitulo.frame = CGRect(x: appImageView.frame.origin.x+appImageView.frame.size.width,
                                   y: labelHora.frame.origin.y+labelHora.frame.size.height,
                                   width: contentView.frame.size.width*0.7,
                                   height: 40)
        labelTitulo.font = .systemFont(ofSize: 20)
        labelTitulo.textAlignment = .center
    }
    
    public func configure(with viewModel: PreviewActividadTableViewCellViewModel) {
        labelTitulo.text = viewModel.titulo
        appImageView.image = viewModel.imagen
        labelHora.text = viewModel.hora
    }

}


