//
//  LectorActividadViewController.swift
//  PowerFitnessApp
//
//  Created by user on 25/7/22.
//

import UIKit
import EventKit

class LectorActividadViewController: UIViewController {
    
    private var eventos: [ActividadGlobal] = []
    private func obtenerEventos() {
        DatabaseManager.shared.getActividadGlobal() { [weak self] eventos in
            self?.eventos = eventos
            print("...   hay \(String(describing: self?.eventos.count)) actividades globales   ...")
        }
    }
    
    private var fechaSeleccionada = Date()
    
    private let navBar = UINavigationBar()
    
    let dia: String
    let titulo: String
    let imagen: UIImage?
    let hora: String
    let descripcion: String
    init(dia: String, titulo: String, imagen: UIImage, hora: String, descripcion: String) {
        self.dia = dia
        self.titulo = titulo
        self.imagen = imagen
        self.hora = hora
        self.descripcion = descripcion
        super.init(nibName: nil, bundle: nil)
    }
    required init?(coder: NSCoder) {
        fatalError()
    }
    
    private let appImageView: UIImageView = {
        let imageView = UIImageView()
        imageView.contentMode = .scaleAspectFill
        return imageView
    }()
    private let labelHora: UILabel = {
        let label = UILabel()
        label.numberOfLines = 0
        return label
    }()
    private let labelDescripcion: UILabel = {
        let label = UILabel()
        label.numberOfLines = 40
        return label
    }()
    
    private let botonApuntarse: UIButton = {
        let button = UIButton()
        button.backgroundColor = .orange
        button.setTitle("Apuntarse", for: .normal)
        button.setTitleColor(.black, for: .normal)
        button.layer.cornerRadius = 8
        button.layer.masksToBounds = true
        return button
    }()
    
    private let fecha: UITextField = {
        let fecha = UITextField()
        fecha.layer.borderWidth = 1
        fecha.layer.borderColor = UIColor.systemGray3.cgColor
        fecha.backgroundColor = .none
        fecha.autocapitalizationType = .none
        fecha.layer.cornerRadius = 8
        fecha.layer.masksToBounds = true
        fecha.textAlignment = .center
        fecha.textColor = .systemGray
        return fecha
    }()
    
    private let labelMaxPers: UILabel = {
        let label = UILabel()
        label.numberOfLines = 0
        return label
    }()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        view.backgroundColor = .systemBackground
        
        obtenerEventos()
        
        view.addSubview(navBar)
        
        appImageView.image = self.imagen
        view.addSubview(appImageView)
        
        labelHora.text = "Hora: " + self.hora
        view.addSubview(labelHora)
        
        labelDescripcion.text = self.descripcion
        view.addSubview(labelDescripcion)
        
        view.addSubview(botonApuntarse)
        botonApuntarse.addTarget(self, action: #selector(didTapApuntarse), for: .touchUpInside)
        
        view.addSubview(fecha)
        self.fecha.datePicker(target: self,
                              doneAction: #selector(doneAction),
                              cancelAction: #selector(cancelAction),
                              datePickerMode: .date)
        
        labelMaxPers.text = "Nº máx de personas por actividad: 5"
        view.addSubview(labelMaxPers)
        
        let item = UINavigationItem(title: self.dia + " " + self.titulo)
        navBar.setItems([item], animated: false)
        navBar.barTintColor = .systemBackground
    }
    
    // MARK: datepicker
    @objc func cancelAction() {
        self.fecha.resignFirstResponder()
    }
    @objc func doneAction() {
        if let datePickerView = self.fecha.inputView as? UIDatePicker {
            let dateFormatter = DateFormatter()
            dateFormatter.dateFormat = "dd/MM/yyyy"
            let dateString = dateFormatter.string(from: datePickerView.date)
            self.fechaSeleccionada = datePickerView.date
            self.fecha.text = dateString
            print("...fecha picker   \(datePickerView.date)   ...")
            print("...formateada picker   \(dateString)   ...")
            self.fecha.resignFirstResponder()
        }
    }
    
    // MARK: boton apuntarse
    @objc private func didTapApuntarse() {
        if (self.fecha.text == "") {
            let alertController = UIAlertController(title: "Error", message: "Selecciona un día primero", preferredStyle: .alert)
            let cancelAction = UIAlertAction(title: "Ok", style: .cancel) {
                UIAlertAction in
                NSLog("Ok Pressed")
            }
            alertController.addAction(cancelAction)
            self.present(alertController, animated: true, completion: nil)
        } else {
            // recoge el iD de la actividad en concreto seleccionada //
            let horaTexto = self.hora.prefix(2)
            let horaEntero = Int(horaTexto) ?? 0
            
            let fechaFinal = self.fechaSeleccionada.setTime(hour: horaEntero, min: 0, sec: 0) // viene del datepicker
            let formatter = DateFormatter()
            formatter.dateFormat = "HH:mm E, d MMM y"
            let formateada = formatter.string(from: fechaFinal!)
            
            let iD = self.titulo + " " + formateada
            //            //             //            //            //
            
            if let apunta2 = self.eventos.first(where: {$0.iD == iD}) {
                if apunta2.apuntados > 4 {
                    let maxAlcanzado = UIAlertController(title: "Error", message: "Se ha alcanzado el número máximo de personas en esta actividad", preferredStyle: .alert)
                    let cancelAction = UIAlertAction(title: "Ok", style: .cancel) {
                        UIAlertAction in
                        NSLog("Ok Pressed")
                    }
                    maxAlcanzado.addAction(cancelAction)
                    self.present(maxAlcanzado, animated: true, completion: nil)
                } else {
                    alertaApuntarse()
                }
            } else {
                alertaApuntarse()
            }
        }
    }
    
    // MARK: alerta apuntarse
    func alertaApuntarse() {
        let alertController = UIAlertController(title: "Aviso", message: "¿Seguro que quieres apuntarte?", preferredStyle: .alert)
        let continuarAction = UIAlertAction(title: "Continuar", style: .default) {
            UIAlertAction in
            NSLog("Continuar Pressed")
            // MARK: se crea el evento y lo añade a firebase
            let store = EKEventStore()
            store.requestAccess(to: .event) { (granted, error) in
                if !granted { return }
                let event = EKEvent(eventStore: store)
                event.title = self.titulo + " " + self.hora + "\nPower Fitness Gym"
                
                // SACAMOS LA HORA DE LA ACTIVIDAD
                let horaTexto = self.hora.prefix(2)
                let horaEntero = Int(horaTexto) ?? 0
                
                let fechaFinal = self.fechaSeleccionada.setTime(hour: horaEntero, min: 0, sec: 0) // viene del datepicker
                event.startDate = fechaFinal
                
                if (self.titulo == "CROSSFIT") {
                    event.endDate = event.startDate.addingTimeInterval(60*119) // 2 hour long
                } else {
                    event.endDate = event.startDate.addingTimeInterval(60*59) // 1 hour long
                }
                
                event.calendar = store.defaultCalendarForNewEvents
                
                // insert of actividad into DB
                let formatter = DateFormatter()
                formatter.dateFormat = "HH:mm E, d MMM y"
                let formateada = formatter.string(from: fechaFinal!)
                let iD = self.titulo + " " + formateada
                
                if let apunta2 = self.eventos.first(where: {$0.iD == iD}) {
                    
                    print("...apunta2 DB   \(apunta2.apuntados)   ...")
                    let apuntadosDB = apunta2.apuntados + 1
                    let actividad = ActividadGlobal(iD: iD, apuntados: apuntadosDB)
                    DatabaseManager.shared.insertActividadGlobal(id: iD, actividad: actividad) { subida in
                        guard subida else {
                            return
                        }
                    }
                    
                } else {
                    let actividad = ActividadGlobal(iD: iD, apuntados: 1)
                    DatabaseManager.shared.insertActividadGlobal(id: iD, actividad: actividad) { subir in
                        guard subir else {
                            return
                        }
                    }
                }
                
                // añadir evento en el calendario
                do {
                    try store.save(event, span: .thisEvent, commit: true)
                    let savedEventId = event.eventIdentifier // save event id to access this particular event later
                    print("...   \(String(describing: event.eventIdentifier))   ...")
                    UserDefaults.standard.set(savedEventId, forKey: "savedEventId")
                    print("...   evento creado   ...")
                } catch {
                    // display error to user
                    NSLog("No se ha podido crear el evento")
                }
            }
            self.dismiss(animated: true, completion: nil) // cierra la vista
        }
        let cancelAction = UIAlertAction(title: "Cancelar", style: .cancel) {
            UIAlertAction in
            NSLog("Cancel Pressed")
        }
        alertController.addAction(continuarAction)
        alertController.addAction(cancelAction)
        self.present(alertController, animated: true, completion: nil)
    }
    
    override func viewDidLayoutSubviews() {
        
        navBar.frame = CGRect(x: 0,
                              y: 0,
                              width: view.frame.size.width,
                              height: 50)
        
        appImageView.frame = CGRect(x: (view.frame.size.width/2)-150,
                                    y: navBar.frame.origin.y+navBar.frame.size.height-5,
                                    width: 300,
                                    height: 300)
        
        labelHora.frame = CGRect(x: 0,
                                 y: appImageView.frame.origin.y+appImageView.frame.size.height,
                                 width: view.frame.size.width,
                                 height: 30)
        labelHora.font = .systemFont(ofSize: 20)
        labelHora.textAlignment = .center
        labelHora.backgroundColor = .orange
        
        labelDescripcion.frame = CGRect(x: 10,
                                        y: labelHora.frame.origin.y+labelHora.frame.size.height,
                                        width: view.frame.size.width-20,
                                        height: 130)
        labelDescripcion.font = .systemFont(ofSize: 14)
        
        botonApuntarse.frame = CGRect(x: 28.3333333333,
                                      y: labelDescripcion.frame.origin.y+labelDescripcion.frame.size.height+10,
                                      width: view.frame.size.width/3,
                                      height: 40)
        fecha.frame = CGRect(x: botonApuntarse.frame.origin.x+botonApuntarse.frame.size.width+10,
                             y: labelDescripcion.frame.origin.y+labelDescripcion.frame.size.height+10,
                             width: view.frame.size.width/2,
                             height: botonApuntarse.frame.size.height)
        
        labelMaxPers.frame = CGRect(x: 0,
                                    y: botonApuntarse.frame.origin.y+botonApuntarse.frame.size.height,
                                    width: view.frame.size.width,
                                    height: 30)
        labelMaxPers.font = .systemFont(ofSize: 14)
        labelMaxPers.textAlignment = .center
        labelMaxPers.textColor = .systemGray
        
    }
    
}

extension UITextField {
    func datePicker<T>(target: T, doneAction: Selector, cancelAction: Selector, datePickerMode: UIDatePicker.Mode = .date) {
        let screenWidth = UIScreen.main.bounds.width
        
        func buttonItem(withSystemItemStyle style: UIBarButtonItem.SystemItem) -> UIBarButtonItem {
            let buttonTarget = style == .flexibleSpace ? nil : target
            let action: Selector? = {
                switch style {
                case .cancel:
                    return cancelAction
                case .done:
                    return doneAction
                default:
                    return nil
                }
            }()
            let barButtonItem = UIBarButtonItem(barButtonSystemItem: style,
                                                target: buttonTarget,
                                                action: action)
            return barButtonItem
        }
        
        let datePicker = UIDatePicker()
        datePicker.frame = CGRect(x: 0, y: 0, width: screenWidth, height: 100)
        datePicker.datePickerMode = datePickerMode
        datePicker.tintColor = .orange
        datePicker.minimumDate = Date()
        self.inputView = datePicker
        
        let toolBar = UIToolbar(frame: CGRect(x: 0,
                                              y: 0,
                                              width: screenWidth,
                                              height: 40))
        toolBar.setItems([buttonItem(withSystemItemStyle: .cancel),
                          buttonItem(withSystemItemStyle: .flexibleSpace),
                          buttonItem(withSystemItemStyle: .done)],
                         animated: true)
        self.inputAccessoryView = toolBar
    }
}

// MARK: extension para añadir una hora a una fecha
extension Date {
    public func setTime(hour: Int, min: Int, sec: Int) -> Date? {
        let x: Set<Calendar.Component> = [.year, .month, .day, .hour, .minute, .second]
        let cal = Calendar.current
        var components = cal.dateComponents(x, from: self)
        components.hour = hour
        components.minute = min
        components.second = sec
        
        return cal.date(from: components)
    }
}


