//
//  LoginViewController.swift
//  PowerFitnessApp
//
//  Created by user on 3/7/22.
//

import UIKit
import FirebaseAuth

class LoginViewController: UIViewController {
    
    private let logo: UIImageView = {
        let logo = UIImageView()
        logo.image = UIImage(named: "logo_pfitness.png")
        logo.contentMode = .scaleAspectFit
        return logo
    }()
    
    private let emailField: UITextField = {
        let emailField = UITextField()
        emailField.attributedPlaceholder = NSAttributedString(
            string: "Correo Electrónico",
            attributes: [NSAttributedString.Key.foregroundColor: UIColor.black]
        )
        emailField.layer.borderWidth = 1
        emailField.layer.borderColor = UIColor.black.cgColor
        emailField.backgroundColor = .none
        emailField.autocapitalizationType = .none
        // para añadir un espacio al meter los datos
        emailField.leftViewMode = .always
        emailField.leftView = UIView(frame: CGRect(x: 0, y: 0, width: 10, height: 0))
        emailField.layer.cornerRadius = 10
        emailField.layer.masksToBounds = true
        return emailField
    }()
    
    private let passField: UITextField = {
        let passField = UITextField()
        passField.attributedPlaceholder = NSAttributedString(
            string: "Contraseña",
            attributes: [NSAttributedString.Key.foregroundColor: UIColor.black]
        )
        passField.layer.borderWidth = 1
        // para añadir caracteres de seguridad al meter la contraseña
        passField.isSecureTextEntry = true
        passField.layer.borderColor = UIColor.black.cgColor
        passField.backgroundColor = .none
        passField.autocapitalizationType = .none
        passField.leftViewMode = .always
        passField.leftView = UIView(frame: CGRect(x: 0, y: 0, width: 10, height: 0))
        passField.layer.cornerRadius = 10
        passField.layer.masksToBounds = true
        return passField
    }()
    
    private let button: UIButton = {
        let button = UIButton()
        button.backgroundColor = .systemOrange
        button.setTitle("Acceder", for: .normal)
        button.setTitleColor(.black, for: .normal)
        button.layer.cornerRadius = 10
        button.layer.masksToBounds = true
        return button
    }()
    
    // crear cuenta
    private let createUserButton: UIButton = {
        let button = UIButton()
        button.setTitle("Crear Usuario", for: .normal)
        button.setTitleColor(.black, for: .normal)
        button.titleLabel?.font = UIFont.systemFont(ofSize: 16)
        return button
    }()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        let backgroundImage = UIImageView(frame: UIScreen.main.bounds)
        backgroundImage.image = UIImage(named: "back_image.jpeg")
        backgroundImage.contentMode = .scaleAspectFill
        self.view.insertSubview(backgroundImage, at: 0)
        // añadimos un efecto difuminado
        let blurEffect = UIBlurEffect(style: .systemUltraThinMaterialLight)
        let blurredEffectView = UIVisualEffectView(effect: blurEffect)
        blurredEffectView.frame = backgroundImage.bounds
        view.addSubview(blurredEffectView)
        
        view.addSubview(logo)
        view.addSubview(emailField)
        view.addSubview(passField)
        view.addSubview(button)
        view.addSubview(createUserButton)
        view.backgroundColor = .white
        button.addTarget(self, action: #selector(didTapButton), for: .touchUpInside)
        createUserButton.addTarget(self, action: #selector(ditTapCreateUser), for: .touchUpInside)
    }
    
    // funcion predefinida para colocar los campos en la vista
    override func viewDidLayoutSubviews() {
        super.viewDidLayoutSubviews()
        
        // vamos a colocar donde queremos que se posicionen todas las imagenes/campos/botones
        logo.frame = CGRect(x: 0,
                            y: (emailField.frame.origin.y-logo.frame.size.height)+view.frame.size.height*0.03,
                            width: view.frame.size.width,
                            height: 400)
        emailField.frame = CGRect(x: 20,
                                  y: view.frame.size.height/2,
                                  width: view.frame.size.width-40,
                                  height: 50)
        // en la 'y' le decimos que coloque el campo de pass diez pixeles por debajo del email
        passField.frame = CGRect(x: 20,
                                 y: emailField.frame.origin.y+emailField.frame.size.height+10,
                                 width: view.frame.size.width-40,
                                 height: 50)
        button.frame = CGRect(x: 20,
                              y: passField.frame.origin.y+passField.frame.size.height+20,
                              width: view.frame.size.width-40,
                              height: 50)
        createUserButton.frame = CGRect(x: view.frame.size.width/2 - (50),
                                        y: button.frame.origin.y+button.frame.size.height+15,
                                        width: 100,
                                        height: 20)
    }
    
    // comprueba si el usuario ya ha iniciado sesion y no necesita volver a introducir sus credenciales
    override func viewDidAppear(_ animated: Bool) {
        super.viewDidAppear(animated)
        // si el usuario ya esta presente en la app redirecciona directamente al contenido
        if FirebaseAuth.Auth.auth().currentUser != nil {
            print("...   has entrado a la app _ ya estaba iniciada la sesion   ...")
            let container = ContainerViewController(nibName: nil, bundle: nil)
            container.modalPresentationStyle = .fullScreen
            self.present(container, animated: true, completion: nil)
        }
    }
    
    // funcion propia para dar funcionamiento al boton de inicio de sesion
    @objc private func didTapButton() {
        print("...   se ha pulsado el inicio de sesion   ...")
        
        guard let email = emailField.text, !email.isEmpty,
              let password = passField.text, !password.isEmpty else {
                  print("...   faltan datos en los campos   ...")
                  faltanCredenciales()
                  return
              }
        
        FirebaseAuth.Auth.auth().signIn(withEmail: email, password: password, completion: { [weak self] result, error in
            guard let strongSelf = self else {
                return
            }
            guard error == nil else {
                // si ocurre un error al iniciar sesion mostramos una alerta
                print("...   credenciales incorrectas   ...")
                strongSelf.showIncorrectCredentials()
                return
            }
            
            // para obtener el email del usuario y asi poder usarlo en otras vistas
            UserDefaults.standard.set(email, forKey: "email")
            
            DispatchQueue.main.async {
                let container = ContainerViewController(nibName: nil, bundle: nil)
                container.modalPresentationStyle = .fullScreen
                self?.present(container, animated: true, completion: nil)
            }
            
            // para ocultar el teclado una vez entremos
            strongSelf.emailField.resignFirstResponder()
            strongSelf.passField.resignFirstResponder()
            print("...   has entrado a la app   ...")
        })
        
    }
    
    // funcion que muestra una alerta al inciar sesion incorrectamente
    func showIncorrectCredentials() {
        let alert = UIAlertController(title: "Error",
                                      message: "Correo electrónico o contraseña incorrectos. \n Inténtelo de nuevo",
                                      preferredStyle: .alert)
        alert.addAction(UIAlertAction(title: "OK",
                                      style: .cancel,
                                      handler: nil
                                     ))
        self.present(alert, animated: true, completion: nil)
    }
    
    @objc private func ditTapCreateUser() {
        print("...   se ha pulsado crear usuario   ...")
        let crearUsuario = CrearUsuarioViewController(nibName: nil, bundle: nil)
        crearUsuario.modalPresentationStyle = .fullScreen
        self.present(crearUsuario, animated: true, completion: nil)
    }
    
    func faltanCredenciales() {
        let alert = UIAlertController(title: "",
                                      message: "Completa todos los campos para acceder",
                                      preferredStyle: .alert)
        alert.addAction(UIAlertAction(title: "OK",
                                      style: .cancel,
                                      handler: nil
                                     ))
        self.present(alert, animated: true, completion: nil)
    }
    
}


